@@ -178,16 +178,16 @@ def execute_order(
         if boolean_allow_partially_filled_orders:
             if float_number_to_be_bought == 0 and float_initial_number_to_be_bought != 0:
                 if dict_display_options['boolean_warning_buy_order_could_not_be_filled']:
-                    print(f'Order execution warning: Buy dict_order for {float_initial_number_to_be_bought} units of {crypto_key} could not be filled.')
+                    print(f'Order execution warning: Buy dict_order for {float_initial_number_to_be_bought} units of {string_crypto_key} could not be filled.')
             elif float_number_to_be_bought < float_initial_number_to_be_bought:
                 if dict_display_options['boolean_warning_buy_order_could_not_be_filled']:
-                    print(f'Order execution warning: Buy dict_order for {float_initial_number_to_be_bought} units of {crypto_key} could only partially be filled: {float_number_to_be_bought} units bought.')
+                    print(f'Order execution warning: Buy dict_order for {float_initial_number_to_be_bought} units of {string_crypto_key} could only partially be filled: {float_number_to_be_bought} units bought.')
             elif float_number_to_be_bought > float_initial_number_to_be_bought:
                 raise ValueError(f'It is not possible that the signal quantity {float_initial_number_to_be_bought} is lower than the final quantity {float_number_to_be_bought} for {order["Asset"]}.')
             return float_number_to_be_bought
         else:
             if float_initial_number_to_be_bought != float_number_to_be_bought:
-                raise InputError('Quantity {float_number_to_be_bought} for {crypto_key} cannot be covered with the given budget or dict_constraints. Maximum {max_possible_quantity} units can be bought.')
+                raise InputError('Quantity {float_number_to_be_bought} for {string_crypto_key} cannot be covered with the given budget or dict_constraints. Maximum {max_possible_quantity} units can be bought.')
             else:
                 return float_number_to_be_bought
 
@@ -235,16 +235,16 @@ def execute_order(
         if boolean_allow_partially_filled_orders:
             if float_number_to_be_bought == 0 and float_initial_number_to_be_bought != 0:
                 if dict_display_options['boolean_warning_buy_order_could_not_be_filled']:
-                    print(f'Order execution warning: Buy dict_order for {float_number_to_be_bought} units of {crypto_key} could not be filled.')
+                    print(f'Order execution warning: Buy dict_order for {float_number_to_be_bought} units of {string_crypto_key} could not be filled.')
             elif float_number_to_be_bought > float_initial_number_to_be_bought:
                 if dict_display_options['boolean_warning_buy_order_could_not_be_filled']:
-                    print(f'Order execution warning: Buy dict_order for {float_number_to_be_bought} units of {crypto_key} could not be filled.')
+                    print(f'Order execution warning: Buy dict_order for {float_number_to_be_bought} units of {string_crypto_key} could not be filled.')
             elif float_number_to_be_bought < float_initial_number_to_be_bought:
                 raise ValueError('It is not possible that the signal quantity {float_initial_number_to_be_bought} is higher (less assets sold) than the final quantity {float_number_to_be_bought} for {order["Asset"]}.')
             return float_number_to_be_bought
         else:
             if float_number_to_be_bought != float_initial_number_to_be_bought:
-                raise InputError('Quantity {float_number_to_be_bought} for {crypto_key} cannot be sold with the given assets or dict_constraints. Maximum {float_number_to_be_bought} units can be sold.')
+                raise InputError('Quantity {float_number_to_be_bought} for {string_crypto_key} cannot be sold with the given assets or dict_constraints. Maximum {float_number_to_be_bought} units can be sold.')
             else:
                 return float_number_to_be_bought
 
@@ -624,7 +624,7 @@ def execute_strategy_multi_asset(
     for index, row in tqdm(df_signals.iterrows(), desc='Going through signals', unit='signal'):
         boolean_buy = None
 
-        crypto_key = index[1]
+        string_crypto_key = index[1]
 
         float_price = find_price(
             df_prices,
@@ -685,7 +685,7 @@ def execute_strategy_multi_asset(
                     ) and (
                         find_dataframe_value_with_keywords(
                             df_trading_journal,
-                            search_term_1=crypto_key,
+                            search_term_1=string_crypto_key,
                             search_column_name_1='Asset'
                         )
                     ) is None
@@ -702,7 +702,7 @@ def execute_strategy_multi_asset(
                         float_number_to_be_bought = (-1) * (
                             find_dataframe_value_with_keywords(
                                 df_trading_journal,
-                                search_term_1=crypto_key,
+                                search_term_1=string_crypto_key,
                                 search_column_name_1='Asset',
                                 output_column_name='Exposure (number)',
                                 first_last_or_all_elements='Last'
@@ -729,7 +729,7 @@ def execute_strategy_multi_asset(
                 boolean_buy=boolean_buy,
                 datetime_datetime=index[0],
                 int_strategy_id=int_chosen_strategy,
-                string_crypto_key=crypto_key,
+                string_crypto_key=string_crypto_key,
                 float_number_to_be_bought=float_number_to_be_bought,
                 df_prices=df_prices,
                 df_trading_journal=df_trading_journal,
